@@ -42,6 +42,7 @@ class Experimento:
                                                             na_values='-',
                                                             usecols=[0],
                                                             engine='python',
+                                                            encoding='latin1',
                                                             ))
         except:
             try:
@@ -51,6 +52,7 @@ class Experimento:
                                                                 na_values='-',
                                                                 usecols=[0],
                                                                 engine='python',
+                                                                encoding='latin1',
                                                                 ))
             except:
                 raise Exception('El archivo ', self.nombre_archivo,
@@ -69,7 +71,8 @@ class Experimento:
                                                   header=0,
                                                   na_values='-',
                                                   skiprows=lista_filas,
-                                                  index_col=False))
+                                                  index_col=False,
+                                                  encoding='latin1'))
             print("Datos procesados.")
         except:
             raise Exception('El archivo ', nombre_recortado.stem, 'no es compatible con motus.')
@@ -131,6 +134,7 @@ class Experimento:
         self.posiciones_y = arreglo_posicion_y
         self.tiempo = arreglo_tiempo
         self.samples = arreglo_samples
+        print("Se encuentra la columna consecuences: ", self.archivo_consecuencias)
         if self.archivo_consecuencias is True:
             self.consecuencias = arreglo_consecuencias
 
@@ -211,8 +215,9 @@ class Experimento:
         self.calcula_distancia_promediada_con_objeto(objeto, intervalo)
         self.calcula_velocidades()
         self.calcula_velocidades_promediadas()
+        self.calcula_regiones_cuadriculadas()
         if genera_matriz_recurrencia is True:
-            self.calcula_regiones_cuadriculadas()
+            self.calcula_matrices_de_recurrencia()
 
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
@@ -388,23 +393,6 @@ class Experimento:
 
         arreglo_region_cuadriculada = self.arreglo_region_cuadriculada
 
-        longitud_matriz_recurrencia = len(arreglo_region_cuadriculada)
-
-        self.matriz_recurrencia_region_cuadriculada = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-
-        self.matriz_recurrencia_objeto_1 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-        self.matriz_recurrencia_objeto_2 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-        self.matriz_recurrencia_objeto_3 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-        self.matriz_recurrencia_objeto_4 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-
-        self.matriz_recurrencia_combinada = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-
         for k in range(cantidad_tiempos):
             # print("Posicion de k:", k)
 
@@ -432,8 +420,37 @@ class Experimento:
                 self.matriz_cuadriculada[i][j] = self.matriz_cuadriculada[i][j] + 1
                 arreglo_region_cuadriculada[k] = cantidad_columnas * i + j
 
+            self.matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
+
+        print(self.matriz_cuadriculada)
+
+    def calcula_matrices_de_recurrencia(self):
+
         self.obtener_indice_regiones_objeto()
 
+        cantidad_tiempos = len(self.tiempo)
+        cantidad_filas = self.cantidad_filas
+        cantidad_columnas = self.cantidad_columnas
+
+        arreglo_region_cuadriculada = self.arreglo_region_cuadriculada
+
+        longitud_matriz_recurrencia = len(arreglo_region_cuadriculada)
+
+        self.matriz_recurrencia_region_cuadriculada = \
+            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+
+        self.matriz_recurrencia_objeto_1 = \
+            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+        self.matriz_recurrencia_objeto_2 = \
+            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+        self.matriz_recurrencia_objeto_3 = \
+            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+        self.matriz_recurrencia_objeto_4 = \
+            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+
+        self.matriz_recurrencia_combinada = \
+            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+
         for i in range(cantidad_tiempos):
             valor = arreglo_region_cuadriculada[i]
             for j in range(cantidad_tiempos):
@@ -456,10 +473,6 @@ class Experimento:
                         self.matriz_recurrencia_objeto_4[i][j] = 1
                         self.matriz_recurrencia_combinada[i][j] = 4
 
-        self.matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
-
-        print(self.matriz_cuadriculada)
-
     def calcula_alturas_cilindros_objetos_relevantes(self, tamanio=24, divisiones=2):
         longitud_movimientos = len(self.posiciones_x)
         valor_min_divivido = int(tamanio / divisiones)
